CREATE USER XLS
  IDENTIFIED BY "change_on_install"
    DEFAULT TABLESPACE USERS
    TEMPORARY TABLESPACE TEMP
    PROFILE "DEFAULT"
    ACCOUNT UNLOCK
    QUOTA UNLIMITED ON USERS;

CREATE TABLE XLS.OBJECTS (
  ID NUMBER,
  TABLE_SCHEMA VARCHAR2(30) NOT NULL,
  TABLE_NAME VARCHAR2(30) NOT NULL,
  TABLE_TYPE VARCHAR2(30) NOT NULL,
  TABLE_CODE NCLOB,
  INSERT_OBJECT NCLOB,
  UPDATE_OBJECT NCLOB,
  DELETE_OBJECT NCLOB,
  CONSTRAINT PK_OBJECTS PRIMARY KEY (ID)
);

CREATE UNIQUE INDEX XLS.IX_OBJECTS ON XLS.OBJECTS (TABLE_SCHEMA, TABLE_NAME);

CREATE SEQUENCE XLS.SQ_OBJECTS_ID
  INCREMENT BY 1
  START WITH 1
  MAXVALUE 1E28
  MINVALUE 1
  NOCYCLE
  CACHE 20
  NOORDER;

CREATE TRIGGER XLS.TR_OBJECTS_ID
  BEFORE INSERT OR UPDATE
  ON XLS.OBJECTS
REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW
BEGIN
  IF :NEW.ID IS NULL THEN
    SELECT SQ_OBJECTS_ID.NEXTVAL INTO :NEW.ID FROM DUAL;
  END IF;
END;
/

CREATE TABLE XLS.HANDLERS
(
  ID NUMBER,
  TABLE_SCHEMA VARCHAR2(30) NOT NULL,
  TABLE_NAME VARCHAR2(30) NOT NULL,
  COLUMN_NAME VARCHAR2(30),
  EVENT_NAME VARCHAR2(30) NOT NULL,
  HANDLER_SCHEMA VARCHAR2(30),
  HANDLER_NAME VARCHAR2(256),
  HANDLER_TYPE VARCHAR2(30),
  HANDLER_CODE NCLOB,
  TARGET_WORKSHEET VARCHAR2(256),
  MENU_ORDER NUMBER(3,0),
  EDIT_PARAMETERS NUMBER(1,0),
  CONSTRAINT PK_HANDLERS
    PRIMARY KEY (ID)
);

CREATE SEQUENCE XLS.SQ_HANDLERS_ID
  INCREMENT BY 1
  START WITH 41
  MAXVALUE 1E28
  MINVALUE 1
  NOCYCLE
  CACHE 20
  NOORDER;

CREATE TRIGGER XLS.TR_HANDLERS_ID
  BEFORE INSERT OR UPDATE
  ON XLS.HANDLERS
REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW
BEGIN
  IF :NEW.ID IS NULL THEN
    SELECT SQ_HANDLERS_ID.NEXTVAL INTO :NEW.ID FROM DUAL;
  END IF;
END;
/

CREATE TABLE XLS.TRANSLATIONS
(
  ID NUMBER,
  TABLE_SCHEMA VARCHAR2(30),
  TABLE_NAME VARCHAR2(30),
  COLUMN_NAME VARCHAR2(30),
  LANGUAGE_NAME CHAR(2) NOT NULL,
  TRANSLATED_NAME NVARCHAR2(61),
  TRANSLATED_DESC NVARCHAR2(1024),
  TRANSLATED_COMMENT NVARCHAR2(2000),
  CONSTRAINT PK_TRANSLATIONS
    PRIMARY KEY (ID)
);

CREATE UNIQUE INDEX XLS.IX_TRANSLATIONS ON XLS.TRANSLATIONS (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, LANGUAGE_NAME);

CREATE SEQUENCE XLS.SQ_TRANSLATIONS_ID
  INCREMENT BY 1
  START WITH 1
  MAXVALUE 1E28
  MINVALUE 1
  NOCYCLE
  CACHE 20
  NOORDER;

CREATE TRIGGER XLS.TR_TRANSLATIONS_ID
  BEFORE INSERT OR UPDATE
  ON XLS.TRANSLATIONS
REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW
BEGIN
  IF :NEW.ID IS NULL THEN
    SELECT SQ_TRANSLATIONS_ID.NEXTVAL INTO :NEW.ID FROM DUAL;
  END IF;
END;
/

CREATE TABLE XLS.FORMATS (
  ID NUMBER,
  TABLE_SCHEMA VARCHAR2(30) NOT NULL,
  TABLE_NAME VARCHAR2(30) NOT NULL,
  TABLE_EXCEL_FORMAT_XML NCLOB,
  CONSTRAINT PK_FORMATS PRIMARY KEY (ID)
);

CREATE SEQUENCE XLS.SQ_FORMATS_ID
  INCREMENT BY 1
  START WITH 21
  MAXVALUE 1E28
  MINVALUE 1
  NOCYCLE
  CACHE 20
  NOORDER;

CREATE TRIGGER XLS.TR_FORMATS_ID
  BEFORE INSERT OR UPDATE
  ON XLS.FORMATS
REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW
BEGIN
  IF :NEW.ID IS NULL THEN
    SELECT SQ_FORMATS_ID.NEXTVAL INTO :NEW.ID FROM DUAL;
  END IF;
END;
/

CREATE UNIQUE INDEX XLS.IX_FORMATS ON XLS.FORMATS (TABLE_SCHEMA, TABLE_NAME);

CREATE TABLE XLS.WORKBOOKS (
  ID NUMBER,
  NAME VARCHAR2(128) NOT NULL,
  TEMPLATE VARCHAR2(255),
  DEFINITION NCLOB NOT NULL,
  TABLE_SCHEMA VARCHAR2(30),
  CONSTRAINT PK_WORKBOOKS PRIMARY KEY (ID)
);

CREATE SEQUENCE XLS.SQ_WORKBOOKS_ID
  INCREMENT BY 1
  START WITH 21
  MAXVALUE 1E28
  MINVALUE 1
  NOCYCLE
  CACHE 20
  NOORDER;

CREATE TRIGGER XLS.TR_WORKBOOKS_ID
  BEFORE INSERT OR UPDATE
  ON XLS.WORKBOOKS
REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW
BEGIN
  IF :NEW.ID IS NULL THEN
    SELECT SQ_WORKBOOKS_ID.NEXTVAL INTO :NEW.ID FROM DUAL;
  END IF;
END;
/

CREATE UNIQUE INDEX XLS.IX_WORKBOOKS ON XLS.WORKBOOKS (NAME);

CREATE OR REPLACE VIEW XLS.QUERIES (
    TABLE_SCHEMA,
    TABLE_NAME,
    TABLE_TYPE,
    TABLE_CODE,
    INSERT_PROCEDURE,
    UPDATE_PROCEDURE,
    DELETE_PROCEDURE,
    PROCEDURE_TYPE
)
AS
SELECT
    t.OWNER AS TABLE_SCHEMA
    , t.OBJECT_NAME AS TABLE_NAME
    , t.OBJECT_TYPE AS TABLE_TYPE
    , NULL AS TABLE_CODE
    , NULL AS INSERT_PROCEDURE
    , NULL AS UPDATE_PROCEDURE
    , NULL AS DELETE_PROCEDURE
    , NULL AS PROCEDURE_TYPE
FROM
    SYS.ALL_OBJECTS t
WHERE
    t.OWNER NOT IN (
        'APEX_030200', 'APPQOSSYS', 'CTXSYS', 'DBSNMP', 'EXFSYS', 'FLOWS_FILES', 'IX', 'MDSYS', 'OLAPSYS',
        'ORDDATA', 'ORDSYS', 'ORDPLUGINS', 'OUTLN', 'OWBSYS', 'SYS', 'SYSTEM', 'SYSMAN', 'WMSYS', 'XDB',
        'XLS', 'SAVETODB_DEV', 'SAVETODB_XLS'
        )
    AND t.OBJECT_TYPE IN ('TABLE', 'VIEW', 'PROCEDURE')
    AND t.OBJECT_NAME NOT LIKE '%_INSERT'
    AND t.OBJECT_NAME NOT LIKE '%_UPDATE'
    AND t.OBJECT_NAME NOT LIKE '%_DELETE'
    AND t.OBJECT_NAME NOT LIKE '%_MERGE'
    AND t.OBJECT_NAME NOT LIKE '%_CHANGE'
    AND t.OBJECT_NAME NOT LIKE 'XL_%';
UNION ALL
SELECT
    o.TABLE_SCHEMA
    , o.TABLE_NAME
    , o.TABLE_TYPE
    , o.TABLE_CODE
    , o.INSERT_OBJECT AS INSERT_PROCEDURE
    , o.UPDATE_OBJECT AS UPDATE_PROCEDURE
    , o.DELETE_OBJECT AS DELETE_PROCEDURE
    , NULL AS PROCEDURE_TYPE
FROM
    XLS.OBJECTS o
WHERE
    o.TABLE_TYPE IN ('CODE', 'HTTP', 'TEXT')
    AND o.TABLE_SCHEMA IS NOT NULL
    AND o.TABLE_NAME IS NOT NULL
    AND o.TABLE_CODE IS NOT NULL
    AND NOT o.TABLE_NAME LIKE 'XL_%'
;

CREATE ROLE XLS_USERS       NOT IDENTIFIED;
CREATE ROLE XLS_DEVELOPERS  NOT IDENTIFIED;

GRANT XLS_USERS TO XLS_DEVELOPERS;

GRANT SELECT ON XLS.OBJECTS         TO XLS_USERS;
GRANT SELECT ON XLS.HANDLERS        TO XLS_USERS;
GRANT SELECT ON XLS.TRANSLATIONS    TO XLS_USERS;
GRANT SELECT ON XLS.FORMATS         TO XLS_USERS;
GRANT SELECT ON XLS.WORKBOOKS       TO XLS_USERS;
GRANT SELECT ON XLS.QUERIES         TO XLS_USERS;

GRANT SELECT ON XLS.QUERIES         TO XLS_DEVELOPERS;

GRANT DELETE, INSERT, SELECT, UPDATE ON XLS.OBJECTS      TO XLS_DEVELOPERS;
GRANT DELETE, INSERT, SELECT, UPDATE ON XLS.HANDLERS     TO XLS_DEVELOPERS;
GRANT DELETE, INSERT, SELECT, UPDATE ON XLS.TRANSLATIONS TO XLS_DEVELOPERS;
GRANT DELETE, INSERT, SELECT, UPDATE ON XLS.FORMATS      TO XLS_DEVELOPERS;
GRANT DELETE, INSERT, SELECT, UPDATE ON XLS.WORKBOOKS    TO XLS_DEVELOPERS;

GRANT SELECT ON XLS.SQ_OBJECTS_ID       TO XLS_DEVELOPERS;
GRANT SELECT ON XLS.SQ_HANDLERS_ID      TO XLS_DEVELOPERS;
GRANT SELECT ON XLS.SQ_TRANSLATIONS_ID  TO XLS_DEVELOPERS;
GRANT SELECT ON XLS.SQ_FORMATS_ID       TO XLS_DEVELOPERS;
GRANT SELECT ON XLS.SQ_WORKBOOKS_ID     TO XLS_DEVELOPERS;

INSERT INTO XLS.HANDLERS (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE) VALUES ('XLS', 'OBJECTS',  'TABLE_TYPE',     'ValidationList', NULL, NULL, 'VALUES', 'TABLE, VIEW, PROCEDURE, CODE, HTTP, TEXT, HIDDEN');
INSERT INTO XLS.HANDLERS (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE) VALUES ('XLS', 'OBJECTS',  'PROCEDURE_TYPE', 'ValidationList', NULL, NULL, 'VALUES', 'TABLE, PROCEDURE, CODE, MERGE');
INSERT INTO XLS.HANDLERS (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE) VALUES ('XLS', 'HANDLERS', 'EVENT_NAME',     'ValidationList', NULL, NULL, 'VALUES', 'Actions, Change, ContextMenu, DoubleClick, SelectionChange, ConvertFormulas, DoNotConvertFormulas, DoNotSelect, DoNotSave, DoNotChange, DoNotAddValidation, DoNotAddChangeHandler, ProtectRows, Formula, FormulaValue, ParameterValues, ValidationList, SelectionList, SyncParameter, DefaultListObject, ManyToMany, DoNotAddManyToMany, AddStateColumn, KeepFormulas, DoNotKeepFormulas, UpdateEntireRow, UpdateChangedCellsOnly');
INSERT INTO XLS.HANDLERS (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE) VALUES ('XLS', 'HANDLERS', 'HANDLER_TYPE',   'ValidationList', NULL, NULL, 'VALUES', 'TABLE, VIEW, PROCEDURE, FUNCTION, CODE, HTTP, TEXT, MACRO, CMD, VALUES, RANGE, REFRESH, MENUSEPARATOR, PDF, REPORT, SHOWSHEETS, HIDESHEETS, SELECTSHEET');
INSERT INTO XLS.HANDLERS (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE) VALUES ('XLS', 'HANDLERS', 'HANDLER_CODE',   'DoNotConvertFormulas', NULL, NULL, NULL, NULL);

INSERT INTO XLS.HANDLERS (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES ('XLS', 'OBJECTS',      NULL, 'Actions', 'XLS', 'SaveToDB Online Help', 'HTTP', 'https://www.savetodb.com/savetodb/configuring-query-list.htm',        NULL, 11, NULL);
INSERT INTO XLS.HANDLERS (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES ('XLS', 'HANDLERS',     NULL, 'Actions', 'XLS', 'SaveToDB Online Help', 'HTTP', 'https://www.savetodb.com/savetodb/configuring-event-handlers.htm',    NULL, 11, NULL);
INSERT INTO XLS.HANDLERS (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES ('XLS', 'TRANSLATIONS', NULL, 'Actions', 'XLS', 'SaveToDB Online Help', 'HTTP', 'https://www.savetodb.com/savetodb/configuring-translation.htm',       NULL, 11, NULL);
INSERT INTO XLS.HANDLERS (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES ('XLS', 'FORMATS',      NULL, 'Actions', 'XLS', 'SaveToDB Online Help', 'HTTP', 'https://www.savetodb.com/savetodb/configuring-table-formats.htm',     NULL, 11, NULL);
INSERT INTO XLS.HANDLERS (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES ('XLS', 'WORKBOOKS',    NULL, 'Actions', 'XLS', 'SaveToDB Online Help', 'HTTP', 'https://www.savetodb.com/savetodb/configuring-workbooks.htm',         NULL, 11, NULL);

INSERT INTO XLS.HANDLERS (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES ('XLS', 'FORMATS',      NULL, 'Actions', 'XLS', 'SaveToDB Framework Online Help', 'HTTP', 'https://www.savetodb.com/help/savetodb-framework-tables.htm#xls.formats', NULL, 12, NULL);
INSERT INTO XLS.HANDLERS (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES ('XLS', 'HANDLERS',     NULL, 'Actions', 'XLS', 'SaveToDB Framework Online Help', 'HTTP', 'https://www.savetodb.com/help/savetodb-framework-tables.htm#xls.handlers', NULL, 12, NULL);
INSERT INTO XLS.HANDLERS (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES ('XLS', 'OBJECTS',      NULL, 'Actions', 'XLS', 'SaveToDB Framework Online Help', 'HTTP', 'https://www.savetodb.com/help/savetodb-framework-tables.htm#xls.objects', NULL, 12, NULL);
INSERT INTO XLS.HANDLERS (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES ('XLS', 'TRANSLATIONS', NULL, 'Actions', 'XLS', 'SaveToDB Framework Online Help', 'HTTP', 'https://www.savetodb.com/help/savetodb-framework-tables.htm#xls.translations', NULL, 12, NULL);
INSERT INTO XLS.HANDLERS (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES ('XLS', 'WORKBOOKS',    NULL, 'Actions', 'XLS', 'SaveToDB Framework Online Help', 'HTTP', 'https://www.savetodb.com/help/savetodb-framework-tables.htm#xls.workbooks', NULL, 12, NULL);

INSERT INTO XLS.WORKBOOKS (NAME, TEMPLATE, DEFINITION, TABLE_SCHEMA) VALUES ('savetodb_configuration.xlsx', NULL, 'objects=XLS.OBJECTS,(Default),False,$B$3,,{"Parameters":{"TABLE_SCHEMA":null,"TABLE_TYPE":null},"ListObjectName":"objects"}
handlers=XLS.HANDLERS,(Default),False,$B$3,,{"Parameters":{"TABLE_SCHEMA":null,"EVENT_NAME":null,"HANDLER_TYPE":null},"ListObjectName":"handlers"}
translations=XLS.TRANSLATIONS,(Default),False,$B$3,,{"Parameters":{"TABLE_SCHEMA":null,"LANGUAGE_NAME":null},"ListObjectName":"translations"}
workbooks=XLS.WORKBOOKS,(Default),False,$B$3,,{"Parameters":{},"ListObjectName":"workbooks"}', 'XLS');

prompt SaveToDB Framework installed
